@@ -1,4 +1,6 @@
 //! Endpoints to create associations with a Matrix ID on the identity server.
 
+pub mod bind_3pid;
+pub mod check_3pid_validity;
 pub mod email;
 pub mod msisdn;
