@@ -22,13 +22,13 @@ ruma_api! {
 impl Request {
     /// Creates an empty `Request`.
     pub fn new() -> Self {
-        Self
+        Self {}
     }
 }
 
 impl Response {
     /// Creates an empty `Response`.
     pub fn new() -> Self {
-        Self
+        Self {}
     }
 }
