@@ -33,6 +33,6 @@ impl Request {
 impl Response {
     /// Creates an empty `Response`.
     pub fn new() -> Self {
-        Self
+        Self {}
     }
 }
